@@ -1,22 +1,18 @@
 ## @knitr contour-layer
-sample_data <- paste0(
-  "https://raw.githubusercontent.com/",
-  "uber-common/deck.gl-data/",
-  "master/website/sf-bike-parking.json"
-)
+data("sf_bike_parking")
 
 contours <- list(
-  contour_definition(
+  use_contour_definition(
     threshold = 1,
     color = c(255, 0, 0),
     strokeWidth = 2
   ),
-  contour_definition(
+  use_contour_definition(
     threshold = 5,
     color = c(0, 255, 0),
     strokeWidth = 3
   ),
-  contour_definition(
+  use_contour_definition(
     threshold = 15,
     color = c(0, 0, 255),
     strokeWidth = 5
@@ -27,11 +23,11 @@ properties <- list(
   contours = contours,
   cellSize = 200,
   elevationScale = 4,
-  getPosition = get_property("COORDINATES")
+  getPosition = ~lng + lat
 )
 
 deck <- deckgl(zoom = 10.5, pitch = 30) %>%
-  add_contour_layer(data = sample_data, properties = properties) %>%
-  add_mapbox_basemap()
+  add_contour_layer(data = sf_bike_parking, properties = properties) %>%
+  add_basemap()
 
 if (interactive()) deck
