@@ -1,21 +1,17 @@
 ## @knitr grid-layer
-sample_data <- paste0(
-  "https://raw.githubusercontent.com/",
-  "uber-common/deck.gl-data/",
-  "master/website/sf-bike-parking.json"
-)
+data("sf_bike_parking")
 
 properties <- list(
   extruded = TRUE,
   cellSize = 200,
   elevationScale = 4,
-  getPosition = get_property("COORDINATES"),
+  getPosition = ~lng + lat,
   getTooltip = JS("object => `${object.position.join(', ')}<br/>Count: ${object.count}`"),
   fixedTooltip = TRUE
 )
 
 deck <- deckgl(zoom = 11, pitch = 45, bearing = 35) %>%
-  add_grid_layer(data = sample_data, properties = properties) %>%
+  add_grid_layer(data = sf_bike_parking, properties = properties) %>%
   add_mapbox_basemap()
 
 if (interactive()) deck
