@@ -7,12 +7,12 @@ sample_data <- paste0(
 
 properties <- list(
   pickable = TRUE,
-  coordinateSystem = JS("COORDINATE_SYSTEM.METER_OFFSETS"),
+  coordinateSystem = JS("deck.COORDINATE_SYSTEM.METER_OFFSETS"),
   coordinateOrigin = c(-122.4, 37.74),
-  radiusPixels = 4,
-  getPosition = get_property("position"),
-  getNormal = get_property("normal"),
-  getColor = get_property("color"),
+  pointSize = 4,
+  getPosition = ~position,
+  getNormal = ~normal,
+  getColor = ~color,
   lightSettings = list(),
   getTooltip = JS("object => object.position.join(', ')")
 )
