@@ -4,10 +4,10 @@ deckgl() %>%
   # Use default icon
   add_icon_layer(
     data = sample_data,
-    getPosition = get_position(coordinates = "coordinates"),
+    getPosition = ~coordinates,
     getColor = JS("d => [Math.sqrt(d.exits), 140, 0]"), # overwrite default color
     pickable = TRUE,
     # onClick = JS("info => console.log(info)")
     onClick = JS("info => deckglWidget.tooltipElement.innerHTML = info.object.name")
   ) %>%
-  add_mapbox_basemap()
+  add_basemap()
